.. _review-ui-hook:

============
ReviewUIHook
============

:py:class:`reviewboard.extensions.hooks.ReviewUIHook` is used to add new UIs to
review specific types of file attachments. For more information, see
:ref:`extension-review-ui-integration`.
